==> dialog-1.0.5-sources.jar: cn/lsmya/dialog/HintDialog.java <==
package cn.lsmya.dialog;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.Gravity;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.TextView;

import androidx.annotation.NonNull;

/**
 * 仿ios提示弹窗
 *
 * @author lsm
 */
public class HintDialog extends Dialog {

    private TextView titleView;
    private TextView contentView;
    private TextView leftButtonView;
    private TextView rightButtonView;

    private Context context;
    private int gravity = Gravity.BOTTOM;
    private String titleStr = "提示";
    private String contentStr;
    private String leftButtonStr = "取消";
    private String rightButtonStr = "确定";
    private int animId = R.style.kit_bottom_menu_animation;

    private OnLeftClickListener onLeftClickListener;
    private OnRightClickListener onRightClickListener;

    public HintDialog(@NonNull Context context, String content) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.contentStr = content;
    }

    public HintDialog(@NonNull Context context, int gravity, String content) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.contentStr = content;
    }

    public HintDialog(@NonNull Context context, String content, int animId) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.contentStr = content;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, int gravity, String content, int animId) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.contentStr = content;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, String content, String leftButton, String rightButton) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
    }

    public HintDialog(@NonNull Context context, int gravity, String content, String leftButton, String rightButton) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
    }

    public HintDialog(@NonNull Context context, String content, String leftButton, String rightButton, int animId) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, int gravity, String content, String leftButton, String rightButton, int animId) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, String title, String content, String leftButton, String rightButton) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.titleStr = title;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
    }

    public HintDialog(@NonNull Context context, int gravity, String title, String content, String leftButton, String rightButton) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.titleStr = title;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
    }

    public HintDialog(@NonNull Context context, String title, String content, String leftButton, String rightButton, int animId) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.titleStr = title;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, int gravity, String title, String content, String leftButton, String rightButton, int animId) {
        super(context, R.style.kit_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.titleStr = title;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
        this.animId = animId;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        Window window = getWindow();
        window.setGravity(gravity);
        window.setWindowAnimations(animId);
        setContentView(R.layout.kit_dialog_hint);
        WindowManager manager = ((Activity) context).getWindowManager();
        DisplayMetrics outMetrics = new DisplayMetrics();
        manager.getDefaultDisplay().getMetrics(outMetrics);
        WindowManager.LayoutParams lp = getWindow().getAttributes();
        lp.width = outMetrics.widthPixels * 9 / 10;
        getWindow().setAttributes(lp);
        setCanceledOnTouchOutside(true);

        titleView = findViewById(R.id.uiDialogHint_title);
        contentView = findViewById(R.id.uiDialogHint_content);
        leftButtonView = findViewById(R.id.uiDialogHint_leftButton);
        rightButtonView = findViewById(R.id.uiDialogHint_rightButton);

        titleView.setText(titleStr);
        contentView.setText(contentStr);
        leftButtonView.setText(leftButtonStr);
        rightButtonView.setText(rightButtonStr);
        leftButtonView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dismiss();
                if (onLeftClickListener != null) {
                    onLeftClickListener.onButtonClick();
                }
            }
        });
        rightButtonView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dismiss();
                if (onRightClickListener != null) {
                    onRightClickListener.onButtonClick();
                }
            }
        });
    }

    public HintDialog setGravity(int gravity) {
        this.gravity = gravity;
        return this;
    }

    public HintDialog setTitle(String title) {
        this.titleStr = title;
        return this;
    }

    public HintDialog setContent(String content) {
        this.contentStr = content;
        return this;
    }

    public HintDialog setLeftButton(String leftButton) {
        this.leftButtonStr = leftButton;
        return this;
    }

    public HintDialog setRightButton(String rightButton) {
        this.rightButtonStr = rightButton;
        return this;
    }

    public HintDialog setOnLeftClickListener(OnLeftClickListener listener) {
        this.onLeftClickListener = listener;
        return this;
    }

    public HintDialog setOnRightClickListener(OnRightClickListener listener) {
        this.onRightClickListener = listener;
        return this;
    }

    public interface OnLeftClickListener {
        void onButtonClick();
    }

    public interface OnRightClickListener {
        void onButtonClick();
    }

    @Override
    public void dismiss() {
        View view = getCurrentFocus();
        if (view instanceof TextView) {
            InputMethodManager mInputMethodManager = (InputMethodManager) getContext().getSystemService(Context.INPUT_METHOD_SERVICE);
            mInputMethodManager.hideSoftInputFromWindow(view.getWindowToken(), InputMethodManager.RESULT_UNCHANGED_SHOWN);
        }
        super.dismiss();
    }
}

==> dialog-1.0.14-sources.jar: cn/lsmya/dialog/HintDialog.java <==
package cn.lsmya.dialog;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.Gravity;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.TextView;

import androidx.annotation.NonNull;

/**
 * 仿ios提示弹窗
 *
 * @author lsm
 */
public class HintDialog extends Dialog {

    private TextView titleView;
    private TextView contentView;
    private TextView leftButtonView;
    private TextView rightButtonView;

    private Context context;
    private int gravity = Gravity.BOTTOM;
    private String titleStr = "提示";
    private String contentStr;
    private String leftButtonStr = "取消";
    private String rightButtonStr = "确定";
    private int animId = R.style.helper_dialog_bottom_menu_animation;

    private OnLeftClickListener onLeftClickListener;
    private OnRightClickListener onRightClickListener;

    public HintDialog(@NonNull Context context, String content) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.contentStr = content;
    }

    public HintDialog(@NonNull Context context, int gravity, String content) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.contentStr = content;
    }

    public HintDialog(@NonNull Context context, String content, int animId) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.contentStr = content;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, int gravity, String content, int animId) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.contentStr = content;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, String content, String leftButton, String rightButton) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
    }

    public HintDialog(@NonNull Context context, int gravity, String content, String leftButton, String rightButton) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
    }

    public HintDialog(@NonNull Context context, String content, String leftButton, String rightButton, int animId) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, int gravity, String content, String leftButton, String rightButton, int animId) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, String title, String content, String leftButton, String rightButton) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.titleStr = title;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
    }

    public HintDialog(@NonNull Context context, int gravity, String title, String content, String leftButton, String rightButton) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.titleStr = title;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
    }

    public HintDialog(@NonNull Context context, String title, String content, String leftButton, String rightButton, int animId) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.titleStr = title;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
        this.animId = animId;
    }

    public HintDialog(@NonNull Context context, int gravity, String title, String content, String leftButton, String rightButton, int animId) {
        super(context, R.style.helper_dialog_bottom_dialog_custom);
        this.context = context;
        this.gravity = gravity;
        this.titleStr = title;
        this.contentStr = content;
        this.leftButtonStr = leftButton;
        this.rightButtonStr = rightButton;
        this.animId = animId;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        Window window = getWindow();
        window.setGravity(gravity);
        window.setWindowAnimations(animId);
        setContentView(R.layout.helper_dialog_hint);
        WindowManager manager = ((Activity) context).getWindowManager();
        DisplayMetrics outMetrics = new DisplayMetrics();
        manager.getDefaultDisplay().getMetrics(outMetrics);
        WindowManager.LayoutParams lp = getWindow().getAttributes();
        lp.width = outMetrics.widthPixels * 9 / 10;
        getWindow().setAttributes(lp);
        setCanceledOnTouchOutside(true);

        titleView = findViewById(R.id.helper_dialog_hint_title);
        contentView = findViewById(R.id.helper_dialog_hint_content);
        leftButtonView = findViewById(R.id.helper_dialog_hint_leftButton);
        rightButtonView = findViewById(R.id.helper_dialog_hint_rightButton);

        titleView.setText(titleStr);
        contentView.setText(contentStr);
        leftButtonView.setText(leftButtonStr);
        rightButtonView.setText(rightButtonStr);
        leftButtonView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dismiss();
                if (onLeftClickListener != null) {
                    onLeftClickListener.onButtonClick();
                }
            }
        });
        rightButtonView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                dismiss();
                if (onRightClickListener != null) {
                    onRightClickListener.onButtonClick();
                }
            }
        });
    }

    public HintDialog setGravity(int gravity) {
        this.gravity = gravity;
        return this;
    }

    public HintDialog setTitle(String title) {
        this.titleStr = title;
        return this;
    }

    public HintDialog setContent(String content) {
        this.contentStr = content;
        return this;
    }

    public HintDialog setLeftButton(String leftButton) {
        this.leftButtonStr = leftButton;
        return this;
    }

    public HintDialog setRightButton(String rightButton) {
        this.rightButtonStr = rightButton;
        return this;
    }

    public HintDialog setOnLeftClickListener(OnLeftClickListener listener) {
        this.onLeftClickListener = listener;
        return this;
    }

    public HintDialog setOnRightClickListener(OnRightClickListener listener) {
        this.onRightClickListener = listener;
        return this;
    }

    public interface OnLeftClickListener {
        void onButtonClick();
    }

    public interface OnRightClickListener {
        void onButtonClick();
    }

    @Override
    public void dismiss() {
        View view = getCurrentFocus();
        if (view instanceof TextView) {
            InputMethodManager mInputMethodManager = (InputMethodManager) getContext().getSystemService(Context.INPUT_METHOD_SERVICE);
            mInputMethodManager.hideSoftInputFromWindow(view.getWindowToken(), InputMethodManager.RESULT_UNCHANGED_SHOWN);
        }
        super.dismiss();
    }
}
